#!/bin/sh
# RAV AntiVirus for Mailservers uninstall script.
# Author: RAV Development Team <ravteam@ravantivirus.com>
# http://www.ravantivirus.com

LIBRAV="/usr/bin/librav-config"

main()
{
distribution
RAV_PRODUCTS=0;
clear
welcome
interface
echo "Press ENTER to continue..."
read x
main
}

distribution()
{
if [ -f /etc/SuSE-release ]; then
    RC_PATH="/etc/init.d"
    INIT_PATH="/etc/init.d"
    LinDst="Suse";
elif [ -f /etc/slackware-version ]; then
    RC_PATH="etc/rc.d"
    INIT_PATH="/etc/rc.d"
    LinDst="Slackware";
elif [ -f /etc/debian_version ]; then
    RC_PATH="/etc"
    INIT_PATH="/etc/init.d"
    LinDst="Debian";
elif [ -f /etc/gentoo-release ]; then
    RC_PATH=""
    INIT_PATH="/etc/init.d"
    LinDst="Gentoo";
else
    RC_PATH="/etc/rc.d"
    INIT_PATH="/etc/rc.d/init.d"
    LinDst="RedHat like";
fi
}
						     

welcome()
{
cat << EOF

				Welcome 

 This script will help you uninstall the RAV AntiVirus for Mailservers product.
 Please note that you must have root privileges in order to uninstall 
 these packages.

EOF


}

interface()
{
cat << EOF

Please select the package(s) that you would like to uninstall 
(please also check the dependencies):

 0. exit without doing anything
EOF

j=1                                                                                   
for i in `$LIBRAV --versions | grep --regexp [0-9] | awk '{print $1}'`; do
  echo -e " $j. $i"                                                                   
  j=$(($j+1));
  explain_package $i
  echo -e "$EXPLANATION"
done
echo ""
if [ $j = 1 ]; then
    rm -fR /opt/rav
    rm -fR /etc/opt/rav
    rm -fR /var/opt/rav
    exit 0
fi
echo -n $n "Component? [0" 
j=1
while [ $j -le $RAV_PRODUCTS ]; do
  echo -n " $j"
  j=$(($j+1))
done
echo "]"
read component
case "$component" in
0|[XxQq]) exit 0  ;;
[123456789]) suretouninstall_package $(get_nth $component) ;;
   *) refresh  ;;
esac

}

refresh()
{
clear
welcome
interface
}

explain_package()
{

EXPLANATION="   unknown package"

if [ "`echo $1 |grep ravcore`x" != "x" ]; then
 export EXPLANATION="   DESCRIPTION: package that contains the scanning engine and the virus signature \n   database\n   NEEDED BY: ravmd, ravfsd"
fi

if [ "`echo $1 |grep ravmd`x" != "x" ]; then
 export EXPLANATION="   DESCRIPTION: RAV mail daemon\n   NEEDED BY: ravexim, ravqmail, ravsendmail, ravcgate, ravpostfix, ravmilter,\n   ravdmail, ravcourier"
fi

if [ "`echo $1 |grep ravqmail`x" != "x" ]; then
 export EXPLANATION="   DESCRIPTION: RAV filter for qmail MTA\n   NEEDS: qmail, ravmd, ravcore "
fi

if [ "`echo $1 |grep ravexim`x" != "x" ]; then
 export EXPLANATION="   DESCRIPTION: RAV filter for exim MTA\n   NEEDS: exim, ravmd, ravcore "
fi

if [ "`echo $1 |grep ravpostfix`x" != "x" ]; then
 export EXPLANATION="   DESCRIPTION: RAV filter for postfix MTA\n   NEEDS: postfix, ravmd, ravcore"
fi

if [ "`echo $1 |grep ravsendmail`x" != "x" ]; then
 export EXPLANATION="   DESCRIPTION: RAV filter for sendmail MTA\n   NEEDS: sendmail, ravmd, ravcore"
fi

if [ "`echo $1 |grep milter`x" != "x" ]; then
 export EXPLANATION="   DESCRIPTION: RAV filter for sendmail with libmilter MTA\n   NEEDS: sendmail with libmilter, ravmd, ravcore"
fi

if [ "`echo $1 |grep ravcgate`x" != "x" ]; then
 export EXPLANATION="   DESCRIPTION: RAV filter for CommuniGate PRO\n   NEEDS: CommuniGate PRO, ravmd, ravcore"
fi

if [ "`echo $1 |grep ravdmail`x" != "x" ]; then
 export EXPLANATION="   DESCRIPTION: RAV filter for DMail MTA\n   NEEDS: DMail, ravmd, ravcore"
fi

if [ "`echo $1 |grep ravcourier`x" != "x" ]; then
 export EXPLANATION="   DESCRIPTION: RAV filter for the Courier MTA\n   NEEDS: Courier, ravmd, ravcore"
fi

if [ "`echo $1 |grep ravfs`x" != "x" ]; then
 export EXPLANATION="   DESCRIPTION: RAV AntiVirus for Unices File Servers\n   NEEDS: ravcore"
fi

if [ "`echo $1 |grep ravfs-sambaclient`x" != "x" ]; then
 export EXPLANATION="   DESCRIPTION: Client for File Scanning Daemon that implements samba's VFS interface\n   NEEDS: ravcore, ravfs-server"
fi

if [ "`echo $1 |grep ravfs-server`x" != "x" ]; then
 export EXPLANATION="   DESCRIPTION: File Scanning Daemon\n   NEEDS: ravcore, ravfs"
fi

}

get_nth()
{
j=1
for i in `$LIBRAV --versions | grep --regexp [0-9] | awk '{print $1}'`; do
  if [ "$j" = "$1" ]; then 
    echo $i
    return
  fi
  j=$(($j+1))
done
echo "unknown"
return
}

suretouninstall_package()
{
echo "selected package: $1"
explain_package $1
echo -e "this package was used for:\n$EXPLANATION"

echo $n "are you sure you wish to uninstall this package ? [y/n] $c"
read ynquestion
case "$ynquestion" in
y|Y) uninstall_package $1 ;;
n|N) echo "not touching $1" ;;
  *) echo "it was a y/n question ..."  ;; 
esac
}

uninstall_package()
{
case "$1" in 
ravcore)		uninstall_ravcore ;;
ravmd)			uninstall_ravmd ;;
ravqmail)		uninstall_ravqmail ;;
ravexim)		uninstall_ravexim ;;
ravpostfix)		uninstall_ravpostfix ;;
ravsendmail)		uninstall_ravsendmail ;;
ravmilter)		uninstall_ravmilter ;;
ravcgate)		uninstall_ravcgate ;;
ravdmail)		uninstall_ravdmail ;;
ravcourier)		uninstall_ravcourier ;;
ravfs)			uninstall_ravfs ;;
ravfs-sambaclient)	uninstall_ravfs_sambaclient ;;
ravfs-server)		uninstall_ravfs_server ;;
esac
}

uninstall_ravcore()
{
#remove the files installed from this package
rm -f /etc/rc.d/init.d/rav
rm -f /etc/opt/rav/rup.conf
rm -f /opt/rav/bin/ravupdate
rm -f /opt/rav/doc/LICENSE
rm -f /opt/rav/doc/ravupdate.pdf
rm -f /opt/rav/man/man8/ravupdate.8.gz
rm -f /opt/rav/doc/ravav.pdf
rm -f /opt/rav/man/man8/ravav.8.gz
rm -f /opt/rav/bin/ravav
rm -fr /var/opt/rav/rave

#remove the symbolic links
rm -f /usr/share/man/man8/ravupdate.8.gz
userdel -r ravms 2>/dev/null
groupdel ravms 2>/dev/null
rm -f /etc/env.d/99rav

#refreshing the file librav-config
cat $LIBRAV | sed s/ravcore_version=.*/ravcore_version='"not installed"'/ > ${LIBRAV}.tmp
mv -f ${LIBRAV}.tmp $LIBRAV                                                           
chmod +x $LIBRAV
}

uninstall_ravmd()
{

killall -TERM ravmd                                                                   
                                                                                      
#remove the files installed from this package
rm -f ${INIT_PATH}/ravmail
rm -f /opt/rav/bin/ravlnggen.sh
rm -f /opt/rav/bin/ravmd
rm -f /opt/rav/bin/ravmdupdate.sh
rm -f /opt/rav/doc/ravmd.conf.pdf
rm -f /opt/rav/doc/ravmd.pdf
rm -fr /opt/rav/lib
rm -f /opt/rav/man/man5/ravmd.conf.5.gz
rm -f /opt/rav/man/man8/ravmd.8.gz

#remove the symbolic links to the libraries                                           
rm -f /opt/rav/lib/librbl.so                                                          
rm -f /opt/rav/lib/libwbl.so                                                          

if [ "${LinDst}" =  "Slackware" ]; then
    sed '/^#ravmd-begin/,/^#ravmd-end/d' < ${INIT_PATH}/rc.local > ${INIT_PATH}/rc.local.sed
    mv -f ${INIT_PATH}/rc.local.sed ${INIT_PATH}/rc.local
    chmod +x ${INIT_PATH}/rc.local
elif [ "${LinDst}" = "Gentoo" ]; then
    rc-update del ravmail default
    rm -f ${INIT_PATH}/ravmail
else
    for i in 0 1 2 3 5 6; do
        rm -f           ${RC_PATH}/rc${i}.d/K40ravmail
        rm -f           ${RC_PATH}/rc${i}.d/S75ravmail
    done
fi
                                             
rm -f /etc/cron.daily/ravmdupdate.sh > /dev/null
rm -f /etc/cron.hourly/ravmdupdate.sh > /dev/null

#refreshing the file librav-config                                                    
cat $LIBRAV | sed s/ravmd_version=.*/ravmd_version='"not installed"'/ > ${LIBRAV}.tmp
mv -f ${LIBRAV}.tmp $LIBRAV                                                           
chmod +x $LIBRAV
}

uninstall_ravqmail()
{
#remove the files installed from this package
rm -f /opt/rav/bin/ravqmail
rm -f /opt/rav/doc/INSTALL
rm -f /opt/rav/doc/LICENSE
rm -f /opt/rav/doc/README
rm -f /opt/rav/doc/UNINSTALL
rm -f /opt/rav/doc/ravqmail.pdf
rm -f /opt/rav/man/man8/ravqmail.8.gz

if [ -d /var/qmail/bin ]; then
    rm -f /var/qmail/bin/qmail-queue
    mv -f /var/qmail/bin/qmail-queue.orig /var/qmail/bin/qmail-queue
else
    echo ""
    echo "You have to make the following modifications manually:"
    echo "su -"
    echo "cd QmailBaseDir/bin"
    echo "rm -f /var/qmail/bin/qmail-queue"
    echo "mv -f /var/qmail/bin/qmail-queue.orig /var/qmail/bin/qmail-queue"
    echo ""
fi

#remove the man page
rm -f /usr/share/man/man8/ravqmail.8.gz

#refreshing the file librav-config
cat $LIBRAV | sed s/ravqmail_version=.*/ravqmail_version='"not installed"'/ > ${LIBRAV}.tmp
mv -f ${LIBRAV}.tmp $LIBRAV
chmod +x $LIBRAV
}

uninstall_ravexim()
{
#remove the files installed from this package
rm -f /opt/rav/bin/ravexim
rm -f /opt/rav/bin/ravexim_filter
rm -f /opt/rav/doc/INSTALL
rm -f /opt/rav/doc/LICENSE
rm -f /opt/rav/doc/README
rm -f /opt/rav/doc/UNINSTALL
rm -f /opt/rav/doc/ravexim.pdf
rm -f /opr/rav/man/man8/ravexim.8.gz

#remove RAV settings from the Exim configuration file
exim_conf=/usr/exim/configure
sed -e '/^#rav-begin/,/^#rav-end/d' \
    -e '/^#rav-transport-begin/,/^#rav-transport-end/d' \
    -e 's/=ravms:/=/' \
  < $exim_conf > $exim_conf.sed && mv -f $exim_conf.sed $exim_conf

#reload exim configuration
if [ -f /var/spool/exim/exim*.pid* ]; then kill -HUP `cat /var/spool/exim/exim-daemon.pid*` > /dev/null
fi
if [ -f /var/lock/exim*.pid* ]; then kill -HUP `cat /var/lock/exim.pid*` > /dev/null
fi

#refreshing the file librav-config
cat $LIBRAV | sed s/ravexim_version=.*/ravexim_version='"not installed"'/ > ${LIBRAV}.tmp
mv -f ${LIBRAV}.tmp $LIBRAV
chmod +x $LIBRAV
}

uninstall_ravpostfix()
{
#remove the files installed from this package
rm -f ${INIT_PATH}/rpostfix
rm -f /opt/rav/bin/ravpostfix
rm -f /opt/rav/doc/INSTALL
rm -f /opt/rav/doc/LICENSE
rm -f /opt/rav/doc/README
rm -f /opt/rav/doc/UNINSTALL
rm -f /opt/rav/doc/ravpostfix.pdf
rm -f /opr/rav/man/man8/ravpostfix.8.gz

main_cf=/etc/postfix/main.cf
master_cf=/etc/postfix/master.cf

#restore the postfix configuration
sed '/^#rav-begin/,/^#rav-end/d' < $main_cf > $main_cf.sed && \
mv -f $main_cf.sed $main_cf
sed '/^#rav-begin/,/^#rav-end/d' < $master_cf > $master_cf.sed && \
mv -f $master_cf.sed $master_cf

#reload postfix
postfix reload > /dev/null

#stop RAV daemon
killall -TERM ravpostfix

#remove starting scripts
if [ "${LinDst}" =  "Slackware" ]; then
    sed '/^#ravpostfix-begin/,/^#ravpostfix-end/d' < ${INIT_PATH}/rc.local > ${INIT_PATH}/rc.local.sed
    mv -f ${INIT_PATH}/rc.local.sed ${INIT_PATH}/rc.local
    chmod +x ${INIT_PATH}/rc.local
elif [ "${LinDst}" = "Gentoo" ]; then
    rc-update del rpostfix default
    rm -f ${INIT_PATH}/rpostfix
else
    for i in 0 1 2 3 5 6; do
	rm -f           ${RC_PATH}/rc${i}.d/K40rpostfix
	rm -f           ${RC_PATH}/rc${i}.d/S75rpostfix
    done
fi

#refreshing the file librav-config                                                    
cat $LIBRAV | sed s/ravpostfix_version=.*/ravpostfix_version='"not installed"'/ > ${LIBRAV}.tmp 
mv -f ${LIBRAV}.tmp $LIBRAV                                                           
chmod +x $LIBRAV
}

uninstall_ravsendmail()
{
#remove the files installed from this package
rm -f /opt/rav/bin/ravsendmail
rm -f /opt/rav/doc/INSTALL
rm -f /opt/rav/doc/LICENSE
rm -f /opt/rav/doc/README
rm -f /opt/rav/doc/UNINSTALL
rm -f /opt/rav/doc/ravsendmail.pdf
rm -f /opt/rav/man/man8/ravsendmail.8.gz

#remove the man page                                                                  
rm -f /usr/share/man/man8/ravsendmail.8.gz                                            
                                                                                      
#restore the sendmail configuration files                                             
if [ -f  /etc/mail/sendmail.cf ]; then                                                
  sendmail_cf=/etc/mail/sendmail.cf                                                   
else
  if [ -f /etc/sendmail.cf ]; then                                                    
      sendmail_cf=/etc/sendmail.cf                                                      
  else
    echo "Could not locate sendmail.cf. Exiting."                                     
    echo                                                                              
    exit 1;                                                                           
  fi                                                                                  
fi

sed -e '/^Sparse=0/,/^SParse0/s/\$#ravsendmail \$@\$1 \$:\$1/\$: \$>Parse1 \$1/' \
    -e '/^#rav-begin/,/^#rav-end/d' < $sendmail_cf > $sendmail_cf.sed   \
    && mv -f $sendmail_cf.sed $sendmail_cf

#reload sendmail configuration file                                                   
killall -HUP sendmail                                                                 
                                                                                      
#stop the second sendmail executable                                                  
killall -TERM sendmail.orig                                                           
                                                                                      
rm -f ${sendmail_cf}.orig                                                             
rm -f /usr/sbin/sendmail.orig	

#refreshing the file librav-config                                                    
cat $LIBRAV | sed s/ravsendmail_version=.*/ravsendmail_version='"not installed"'/ > ${LIBRAV}.tmp
mv -f ${LIBRAV}.tmp $LIBRAV                                                           
chmod +x $LIBRAV
}

uninstall_ravmilter()
{
#remove the files installed from this package
rm -f ${INIT_PATH}/ravmilter
rm -f /opr/rav/bin/RAVMilter
rm -f /opt/rav/doc/INSTALL
rm -f /opt/rav/doc/LICENSE
rm -f /opt/rav/doc/RAVMilter.pdf
rm -f /opt/rav/doc/README
rm -f /opt/rav/doc/UNINSTALL
rm -f /opr/rav/man/man8/RAVMilter.8.gz

killall -TERM RAVMilter

if [ "${LinDst}" =  "Slackware" ]; then
    sed '/^#ravmilter-begin/,/^#ravmilter-end/d' < ${INIT_PATH}/rc.local > ${INIT_PATH}/rc.local.sed
    mv -f ${INIT_PATH}/rc.local.sed ${INIT_PATH}/rc.local
    chmod +x ${INIT_PATH}/rc.local
elif [ "${LinDst}" = "Gentoo" ]; then
    rc-update del ravmilter default
    rm -f ${INIT_PATH}/ravmilter
else
    for i in 0 1 2 3 5 6; do
	rm -f           /etc/rc.d/rc${i}.d/K40ravmilter
	rm -f           /etc/rc.d/rc${i}.d/S75ravmilter
    done
fi

generic_which()
{
b=false
IFS=:
for d in $PATH; do
    if [ -x $d/$1 ]; then
	b=$d/$1
    fi
done
echo $b
}

m4=`(generic_which m4)`

#remove the RAV settings from the sendmail configuration file
sendmail_mc=/etc/mail/sendmail.mc
sendmail_cf=/etc/mail/sendmail.cf

if [ -f $sendmail_mc ]; then
    sed '/^dnl rav-begin/,/^dnl rav-end/d' < $sendmail_mc > $sendmail_mc.sed \
    && mv -f $sendmail_mc.sed $sendmail_mc
    if [ "$m4" != "false" ]; then
	$m4 $sendmail_mc > $sendmail_cf
    fi
fi

#reload sendmail configuration file
killall -HUP sendmail

#refreshing the file librav-config
cat $LIBRAV | sed s/ravmilter_version=.*/ravmilter_version='"not installed"'/ > ${LIBRAV}.tmp
mv -f ${LIBRAV}.tmp $LIBRAV                                                           
chmod +x $LIBRAV

}

uninstall_ravcgate()
{
#remove the files installed from this package
rm -f /opr/rav/bin/ravcgate
rm -f /opt/rav/doc/INSTALL
rm -f /opt/rav/doc/LICENSE
rm -f /opt/rav/doc/README
rm -f /opt/rav/doc/UNINSTALL
rm -f /opt/rav/doc/ravcgate.pdf
rm -f /opr/rav/man/man8/ravcgate.8.gz

#remove the filter link
rm -f /var/CommuniGate/ravcgate
#remove the man page
rm -f /usr/share/man/man8/ravcgate.8.gz

#refreshing the file librav-config
cat $LIBRAV | sed s/ravcgate_version=.*/ravcgate_version='"not installed"'/ > ${LIBRAV}.tmp
mv -f ${LIBRAV}.tmp $LIBRAV
chmod +x $LIBRAV
}

uninstall_ravdmail()
{
#remove the files installed from this package
rm -f /opr/rav/bin/ravdmail
rm -f /opt/rav/doc/INSTALL
rm -f /opt/rav/doc/LICENSE
rm -f /opt/rav/doc/README
rm -f /opt/rav/doc/UNINSTALL
rm -f /opt/rav/doc/ravdmail.pdf
rm -f /opr/rav/man/man8/ravdmail.8.gz

dmail_conf=/etc/dmail.conf

#erase RAV settings from the DMail configuration file
sed '/^#rav-begin/,/^#rav-end/d' < $dmail_conf > $dmail_conf.sed && \
mv -f $dmail_conf.sed $dmail_conf

#reload DMail SMTP server configuration
tellsmtp reload

#remove the man page
rm -f /usr/share/man/man8/ravdmail.8.gz

#refreshing the file librav-config
cat $LIBRAV | sed s/ravdmail_version=.*/ravdmail_version='"not installed"'/ > ${LIBRAV}.tmp
mv -f ${LIBRAV}.tmp $LIBRAV
chmod +x $LIBRAV
}

uninstall_ravcourier()
{
#remove the files installed from this package                                         
rm -f /etc/opt/rav/ravcourier.conf
rm -f /opr/rav/bin/ravcourier
rm -f /opt/rav/doc/INSTALL
rm -f /opt/rav/doc/LICENSE
rm -f /opt/rav/doc/README
rm -f /opt/rav/doc/UNINSTALL
rm -f /opt/rav/doc/ravcourier.pdf
rm -f /opr/rav/man/man8/ravdmail.8.gz

#uninstall ravcourier filter
/usr/lib/courier/sbin/filterctl stop ravcourier

#remove the man page
rm -f /usr/share/man/man8/ravcourier.8.gz

#remove the symbolic link from the courier filters
rm -f /usr/lib/courier/libexec/filters/ravcourier

#refreshing the file librav-config                                                    
cat $LIBRAV | sed s/ravcourier_version=.*/ravcourier_version='"not installed"'/ > ${LIBRAV}.tmp
mv -f ${LIBRAV}.tmp $LIBRAV                                                           
chmod +x $LIBRAV
}



uninstall_ravfs()
{
#remove the files installed from this package                                         
rm -f /opt/rav/doc/README.ravfs
rm -f /opt/rav/doc/LICENSE.ravfs

#refreshing the file librav-config                                                    
cat $LIBRAV | sed s/ravfs_version=.*/ravfs_version='"not installed"'/ > ${LIBRAV}.tmp
mv -f ${LIBRAV}.tmp $LIBRAV                                                           
chmod +x $LIBRAV
}


uninstall_ravfs_sambaclient()
{
#remove the files installed from this package                                         
rm -f /opt/rav/lib/ravsamba.so*
rm -f /opt/rav/lib/smblink.sh
rm -fr /opt/rav/lib
rm -f /opt/rav/man/man8/ravsamba.8.gz

#remove the man page
rm -f /usr/share/man/man8/ravsamba.8.gz

#refreshing the file librav-config                                                    
cat $LIBRAV | sed s/ravfs_sambaclient_version=.*/ravfs_sambaclient_version='"not installed"'/ > ${LIBRAV}.tmp
mv -f ${LIBRAV}.tmp $LIBRAV                                                           
chmod +x $LIBRAV
}


uninstall_ravfs_server()
{

/etc/init.d/ravfsd stop &>/dev/null

#remove starting scripts
if [ "${LinDst}" =  "Slackware" ]; then
    sed '/^#ravfs-begin/,/^#ravfs-end/d' < ${INIT_PATH}/rc.local > ${INIT_PATH}/rc.local.sed
    mv -f ${INIT_PATH}/rc.local.sed ${INIT_PATH}/rc.local
    chmod +x ${INIT_PATH}/rc.local
elif [ "${LinDst}" = "Gentoo" ]; then
    rc-update del ravfsd default
    rm -f ${INIT_PATH}/ravfsd
else
    for i in 0 1 2 3 5 6; do
	rm -f           ${RC_PATH}/rc${i}.d/K40ravfsd
	rm -f           ${RC_PATH}/rc${i}.d/S75ravfsd
    done
fi


#removing the symlinks
rm -f /usr/share/man/man8/ravfsd.8.gz
rm -f /usr/share/man/man5/ravfsd.conf.5.gz
rm -f /etc/cron.daily/ravfsdupdate.sh
rm -f /etc/cron.hourly/ravfsdupdate.sh
														

#remove the files installed from this package                                         
rm -f /etc/init.d/ravfsd
rm -f /etc/opt/rav/ravfsd.conf
rm -f /etc/opt/rav/ravfsdupdate.conf
rm -f /opt/rav/bin/ravfsd
rm -f /opt/rav/bin/ravfsdupdate.sh
rm -f /opt/rav/man/man5/ravfsd.conf.5.gz
rm -f /opt/rav/man/man8/ravfsd.8.gz


#refreshing the file librav-config                                                    
cat $LIBRAV | sed s/ravfs_server_version=.*/ravfs_server_version='"not installed"'/ > ${LIBRAV}.tmp
mv -f ${LIBRAV}.tmp $LIBRAV                                                           
chmod +x $LIBRAV
}


main
